class KarmaGun extends P2Weapon;

const DEF_HOLD_DIST = 80;
const MAX_CHARGE_TIME = 2.0;

var Actor OurHeldItem; // pointer to the box or whatever we're carrying
var float HoldDist; // how far away the dude holds it from his body
var float ThrowMomentum;
var float KThrowMomentum;
var float PThrowMomentum; // Momentum of projectile grabbed and thrown.
var sound ErrorSound;
var sound LaughSound;
var sound FlipOffSound;
var bool OldbPawn;
var float ChargeTime;
var float ChargeStart;

var bool bShowMainHints;
var localized string HudHint3;
var localized string HudHint4;
var color ProgressBarColor;

replication
{
	reliable if (Role == ROLE_Authority)
		OurHeldItem, HoldDist, ClientGoHoldItem, PlayCaught, PlayAltFireSound;
	reliable if (Role < ROLE_Authority)
		TossOurItem;
}

///////////////////////////////////////////////////////////////////////////////
// bBumpStartsFight not working in defaults
///////////////////////////////////////////////////////////////////////////////
simulated event PostBeginPlay()
{
	Super.PostBeginPlay();
	bBumpStartsFight=false;
}

function exec Dance1()
{
    Instigator.PlayAnim('s_dance1');
}

function exec Dance2()
{
    Instigator.PlayAnim('s_dance2');
}

function exec Dance3()
{
    Instigator.PlayAnim('s_dance3');
}

function exec Laugh()
{
    Instigator.PlayAnim('s_laugh');
    Instigator.PlaySound(LaughSound);
}

function exec FlipOff()
{
    Instigator.PlayAnim('s_midfinger');
    Instigator.PlaySound(FlipOffSound);
}

///////////////////////////////////////////////////////////////////////////////
// Draw percentage bar
///////////////////////////////////////////////////////////////////////////////
simulated function DrawPercBar(Canvas Canvas, float ScreenX, float ScreenY, float Width, float Height, float Border, Color Fore, float Perc)
{
	local float InnerWidth;
	local float InnerHeight;

	Canvas.Style = ERenderStyle.STY_Alpha;

	Canvas.SetPos(ScreenX - (Width/2), ScreenY);
	Canvas.SetDrawColor(0,0,0,byte(float(Fore.A)*0.75));
	if (Canvas.DrawColor.A > 0)
		Canvas.DrawRect(Texture'engine.WhiteSquareTexture', Width, Height);

	InnerWidth = Width - 2 * Border;
	InnerHeight = Height - 2 * Border;

	Canvas.SetPos(ScreenX - (InnerWidth/2), ScreenY + Border);
	Canvas.DrawColor = Fore;
	if (Canvas.DrawColor.A > 0)
		Canvas.DrawRect(Texture'engine.WhiteSquareTexture', InnerWidth * Perc, InnerHeight);
}

///////////////////////////////////////////////////////////////////////////////
// Allow two sets of hud hints to explain primary, then alternative fire
///////////////////////////////////////////////////////////////////////////////
simulated function TurnOffHint()
{
	if(bShowMainHints)
	{
		bShowMainHints=false;
		// Swap out hints to show
		HudHint1 = HudHint3;
		HudHint2 = HudHint4;
		UpdateHudHints();
	}
	else
		Super.TurnOffHint();
}

function bool IsConstrained(KActor Other)
{
	local KConstraint KC;

	foreach DynamicActors(class'KConstraint', KC)
		if (KC.KConstraintActor1 == Other || KC.KConstraintActor2 == Other)
			return true;

	return false;
}

simulated function PlayFiring(); // stubbed out because we don't want animations
simulated function PlayAltFiring();
simulated function ClientIdleCheckFire(); // stubbed out because we don't automatically continue firing

simulated function PlayCaught()
{
	TurnOffHint();
	Instigator.PlaySound(FireSound, SLOT_None, 1.0, true, , WeaponFirePitchStart + (FRand()*WeaponFirePitchRand));
}

simulated function PlayAltFireSound()
{
	Instigator.PlaySound(AltFireSound, SLOT_None, 1.0, true, , WeaponFirePitchStart + (FRand()*WeaponFirePitchRand));
}

function DropOurItem() // function to get rid of whatever item we're carrying
{
	local P2Pawn OPawn;
	local Controller OController;
	local MolotovProjectile MProj;
	// Molotovs are the biggest prick projectile, unwilling to cooperate with
	// the changes of velocity, so we might as well spawn a new one.

    if (OurHeldItem != None)
	{
		if ( P2Pawn(Owner) != None )
		{
			OPawn = P2Pawn(Owner);
		}
        if (IsSeveredHead(OurHeldItem))
		{
			OurHeldItem.SetPhysics(PHYS_Projectile);
			OurHeldItem.Acceleration.Z = Head(OurHeldItem).HEAD_GRAVITY;
		}
		else
		if ( P2Projectile(OurHeldItem) != None )
		// Some projectiles require some additional changes to some of their
		// properties
		{
            if ( ScissorsProjectile(OurHeldItem) != None )
            {
                ScissorsProjectile(OurHeldItem).Velocity = (vect(0,0,0));
                // When the Karma gun holds the scissors, it "cancels" out it's
                // movement, so dropping the scissor should reflect that.
            }
            else
            if ( CowHeadProjectile(OurHeldItem) != None )
            {
                CowHeadProjectile(OurHeldItem).TakeDamage( 1, OPawn, CowHeadProjectile(OurHeldItem).Location, (Vect(0,0,0)), Class'BaseFX.KickingDamage' );
                // We want dropping it to count as a light kick, so we need to
                // "cause" damage. The light "kick" causes the cowhead to move
                // correctly such as bouncing and producing Anth Clouds.
                CowHeadProjectile(OurHeldItem).Health += 1;
                // We had the health back so it's like it was never hit to
                // begin with.s
                CowHeadProjectile(OurHeldItem).Velocity = OPawn.Velocity;
                // Once we drop something, it should have the same velocity as
                // the dropper. If you're moving, it's moving, if you're not,
                // it won't
            }
            else
            if ( GrenadeProjectile(OurHeldItem) != None )
            {
                if ( MolotovProjectile(OurHeldItem) != None )
                {
                    MolotovProjectile(OurHeldItem).Destroy();
                    // We destroy the one thrown at us so the newly spawn one
                    // can take it's place.
                    MProj = Spawn( class'MolotovAltProjectile', OPawn,, MolotovProjectile(OurHeldItem).Location, MolotovProjectile(OurHeldItem).Rotation );
                    // We spawn the new one in the same place, and same
                    // rotation as the old one. Since we always spawn alt
                    // molotovs for dropping them, we can grab the flying
                    // molotov, and set them carefully back on the ground
                    // without them exploding in our face.
                    MProj.Velocity = OPawn.Velocity;
                    // Add some velocity from the dropper.
                }
                else
                {
                    GrenadeProjectile(OurHeldItem).TakeDamage( 1, OPawn, GrenadeProjectile(OurHeldItem).Location, (Vect(0,0,0)), Class'BaseFX.KickingDamage' );
                    // Same goes for the Cow head, this counts as a real light kick
                    // so the projectile will behave correctly. Otherwise it might
                    // be floating at times. It also needs to take a minimum of 1
                    // damage so the function will be put into effect.
                    GrenadeProjectile(OurHeldItem).Health += 1;
                    // Cancel out the one damage, so it moves, but it's like it
                    // never took the damage to begin with. For Moltovs, this
                    // shouldn't really do anything.
                    GrenadeProjectile(OurHeldItem).Velocity = OPawn.Velocity;
                    // Dropping it will mean it'll also travel at the same speed as
                    // the dropper, if he ain't moving, neither will the projectile.
                    // If he is, then the projectile will be moving at the same
                    // speed.
		        }
            }
        }
		else
		if ( FPSPawn(OurHeldItem) != None )
        {
            // We don't do anything for dropping pawns. We just, drop'em, and
            // let'em do whatever they want.
        }
        else
		{
			OurHeldItem.SetPhysics(PHYS_Karma); // turn karma physics back on
			//if (!OurHeldItem.KIsAwake())
				OurHeldItem.KWake(); // give it a jolt so it'll fall to the ground
//			OurHeldItem.KAddImpulse(Vect(0,0,0), OurHeldItem.Location);
			KActor(OurHeldItem).bPawnMovesMe=OldbPawn;
		}
		OurHeldItem.bBlockPlayers=true; // have it block players again
		OurHeldItem = None; // reset our pointer
	}
}

function TossOurItem(float Charge) // function to get rid of whatever item we're carrying
{
	local vector UseMom;
	local vector KUseMom;
	local vector PUseMom; // Added this for projectiles.
	local P2Pawn OPawn;
	local Controller OController;
	local float C;
	local MolotovProjectile MProj;
	// Molotovs are the biggest prick projectile, unwilling to cooperate with
	// the changes of velocity, so we might as well spawn a new one.

	if (OurHeldItem != None)
	{
		if (Charge < 0.5)
			C = 0.5;
		else
			C = Charge;
		if (P2Pawn(Owner) != None)
		{
			OPawn = P2Pawn(Owner);
			OController = OPawn.Controller;
			UseMom = ThrowMomentum * Normal(Vector(OController.GetViewRotation())) * C;
			KUseMom = KThrowMomentum * Normal(Vector(OController.GetViewRotation())) * C;
			PUseMom = PThrowMomentum * Normal(Vector(OController.GetViewRotation())) * C;
			OurHeldItem.Instigator = OPawn;
		}
		if (IsSeveredHead(OurHeldItem))
		{
			OurHeldItem.SetPhysics(PHYS_Projectile);
			Head(OurHeldItem).GiveMomentum(UseMom);
			if (OPawn != None)
				Head(OurHeldItem).PlayerMovedMe = OPawn;
		}
		else
		if ( P2Projectile(OurHeldItem) != None )
		// Here we prep certain projectiles such as Cow heads for flight. Then
		// after being prepped, the velocity is added to the projectile.
		{
            if ( CowHeadProjectile(OurHeldItem) != None )
            {
                CowHeadProjectile(OurHeldItem).TakeDamage( 1, OPawn, CowHeadProjectile(OurHeldItem).Location, PUseMom, Class'BaseFX.KickingDamage' );
                // Like before, this counts as a "kick" prepping it for flight.
                CowHeadProjectile(OurHeldItem).Health += 1;
                // Add back the 1 health lost, so it's like it never took the
                // damage to begin with.
            }
            else
            if ( GrenadeProjectile(OurHeldItem) != None )
            {
                if ( MolotovProjectile(OurHeldItem) != None )
                {
                    MolotovProjectile(OurHeldItem).Destroy();
                    // Like when we drop the projectile, we will destroy it,
                    // and replace it with a new one.
                    MProj = Spawn( class'MolotovProjectile', OPawn,, MolotovProjectile(OurHeldItem).Location, MolotovProjectile(OurHeldItem).Rotation );
                    // When we're throwing it away, we always use the regular
                    // molotov projectile, which means we'll turn any carefully
                    // dropped molotov and turn it into a lethal thrown one.
                    MProj.Velocity = PUseMom;
                    // Now we add the velocity for projectiles.
                    MProj.RandSpin(20000);
                    // And make it spin for an authentic toss-like look.
                }
                else
                {
                    GrenadeProjectile(OurHeldItem).TakeDamage( 1, OPawn, GrenadeProjectile(OurHeldItem).Location, PUseMom, Class'BaseFX.KickingDamage' );
                    // Like before, this counts as a kick with a minimum of 1 damage
                    // so the function will work.
                    GrenadeProjectile(OurHeldItem).Health += 1;
                    // Then we add back one extra health so it's like it never took
                    // any damage. If the grenade is stressed enough from getting
                    // kicked, it will explode, so beware, but if you've been doing
                    // nothing but using the karma gun to move it, you can do it an
                    // infinite number of times.
                }
            }
            else
            if ( LauncherSeekingProjectileTrad(OurHeldItem) != None )
            {
                LauncherSeekingProjectileTrad(OurHeldItem).BounceMax = 1;
                // We want the rocket to blow up on contact, not bounce on a
                // wall and back to us.
                LauncherSeekingProjectileTrad(OurHeldItem).SetupShot(0);
                // Make the rocket run out of fuel, at the same time cancel out
                // it's homing capability. The velocity added is more then
                // enough to send the rocket back to the launcher.
            }
            else
            if ( PlagueProjectile(OurHeldItem) != None )
            {
                PlagueProjectile(OurHeldItem).Acceleration = (vect(0,0,0));
                // First, we cancel out it's acceleration so once we send it
                // back, it won't accelerate somewhere off target or right back
                // to ya.
                PlagueProjectile(OurHeldItem).SetupShot(0);
                // We take out it's fuel so bouncing projectiles won't bounce
                // around as much causing havoc.
            }
            P2Projectile(OurHeldItem).Velocity = PUseMom;
            // Now that we're done prepping certain projectiles above, we send
            // them off by giving them velocity.
		}
        else
        if ( FPSPawn(OurHeldItem) != None )
        {
            FPSPawn(OurHeldItem).Velocity = PUseMom;
            // If it's a pawn, just throw them off.
        }
        else
		{
			OurHeldItem.SetPhysics(PHYS_Karma); // turn karma physics back on
			//if (!OurHeldItem.KIsAwake())
			//	OurHeldItem.KWake(); // give it a jolt so it'll fall to the ground
			OurHeldItem.KAddImpulse(KUseMom, OurHeldItem.Location);
			KActor(OurHeldItem).bPawnMovesMe=OldbPawn;
		}
		PlayAltFireSound();
		OurHeldItem.bBlockPlayers=true; // have it block players again
		OurHeldItem = None; // reset our pointer
	}
}

function bool IsSeveredHead(actor Other)
{
	if (Head(Other) != None)
		if (Head(Other).MyBody == None)
			return true;

	return false;
}

simulated function Fire(float Value)
{
	ServerFire();
}

simulated function AltFire( float Value )
{
	bAltFiring=true;
	ServerAltFire();
	ChargeTime=0;

	if ( Role < ROLE_Authority && OurHeldItem != None )
	{
		GotoState('ChargingThrow');
	}
}

simulated function ClientGoHoldItem()
{
	GotoState('HoldingItem');
}

///////////////////////////////////////////////////////////////////////////////
// Normal trace fire, plus check where to make the danger marker to
// alert people of the noise.
///////////////////////////////////////////////////////////////////////////////
function TraceFire( float Accuracy, float YOffset, float ZOffset )
{
	local Actor BasedActor;
	local vector markerpos, markerpos2;
	local bool secondary;
	local BulletTracer bullt;
	local vector usev;
	local Rotator newrot;
	local vector HitNormal, StartTrace, EndTrace, X,Y,Z;
	local actor Other;

	//log("TraceFire called");

	if (OurHeldItem == None) // if not holding an item, look to see if we can pick one up
	{
		// Weapon.TraceFire (modified to save where it hit inside LastHitLocation
		GetAxes(Instigator.GetViewRotation(),X,Y,Z);
		StartTrace = GetFireStart(X,Y,Z);
		AdjustedAim = Instigator.AdjustAim(AmmoType, StartTrace, 2*AimError);
		EndTrace = StartTrace + (YOffset + Accuracy * (FRand() - 0.5 ) ) * Y * 1000
			+ (ZOffset + Accuracy * (FRand() - 0.5 )) * Z * 1000;
		X = vector(AdjustedAim);
		EndTrace += (TraceDist * X);
		// This performs the collision but also records where it hit
		Other = Trace(LastHitLocation,HitNormal,EndTrace,StartTrace,True);
		//log("Hit actor was" @ Other);
		if (KActor(Other) != None || IsSeveredHead(Other)) // this is a karma actor, so let's grab it
		{
			BasedActor = None;
			foreach Other.BasedActors(class'Actor', BasedActor)
				break;
			if (BasedActor == None)
			{
				foreach Other.TouchingActors(class'Actor', BasedActor)
					break;
			}

			if (KActor(Other) != None && IsConstrained(KActor(Other)))
				BasedActor = Other;

			// Crash prevention: Don't pick up karma objects with based actors
			if (BasedActor == None)
			{
				//log ("Karma physics detected, grabbing item");
				OurHeldItem = Other;
				ClientGoHoldItem();
				PlayCaught();
				GotoState ('HoldingItem');
			}
			else
				Other.PlaySound(ErrorSound, SLOT_MISC);
		}
		else
		if ( P2Projectile(Other) != None )
		// If it's just a projectile, just get them.
		{
            BasedActor = None;
			foreach Other.BasedActors(class'Actor', BasedActor)
				break;
			if (BasedActor == None)
			{
				foreach Other.TouchingActors(class'Actor', BasedActor)
					break;
			}

			if (KActor(Other) != None && IsConstrained(KActor(Other)))
				BasedActor = Other;

			OurHeldItem = Other;
			ClientGoHoldItem();
			PlayCaught();
			GotoState ('HoldingItem');
		}
		else
		if ( Pickup(Other) != None )
		// If it's just a projectile, just get them.
		{
            BasedActor = None;
			foreach Other.BasedActors(class'Actor', BasedActor)
				break;
			if (BasedActor == None)
			{
				foreach Other.TouchingActors(class'Actor', BasedActor)
					break;
			}

			if (KActor(Other) != None && IsConstrained(KActor(Other)))
				BasedActor = Other;

			OurHeldItem = Other;
			ClientGoHoldItem();
			PlayCaught();
			GotoState ('HoldingItem');
		}
		else
		if ( FPSPawn(Other) != None && FPSPawn(Other).Health > 0 )
		{
		// Same with pawns.
			BasedActor = None;
			foreach Other.BasedActors(class'Actor', BasedActor)
				break;
			if (BasedActor == None)
			{
				foreach Other.TouchingActors(class'Actor', BasedActor)
					break;
			}

			if (KActor(Other) != None && IsConstrained(KActor(Other)))
				BasedActor = Other;

			OurHeldItem = Other;
			ClientGoHoldItem();
			PlayCaught();
			GotoState ('HoldingItem');
		}
		else // not a karma actor, ignore
		{
			//log ("No karma physics detected");
			//GotoState('NormalFire');
		}
	}
	else // if we're holding an item, drop it
	{
		//log ("Dropping held item");
		DropOurItem();
		//GotoState('Idle');
	}
}

///////////////////////////////////////////////////////////////////////////////
// Alt trace fire, plus check where to make the danger marker to
// alert people of the noise.
///////////////////////////////////////////////////////////////////////////////
function TraceAltFire( float Accuracy, float YOffset, float ZOffset )
{
	if (OurHeldItem != None)
	{
		GotoState('ChargingThrow');
	}
}

state ClientFiring
{
}

state NormalFire // thrown in to prevent the game from crashing
{
Begin:
	Sleep(0.25);
	GotoState('Idle');
}

// HoldingItem
// An extension of weapon idle, since we're not really firing
// Grab our item and drag it along with the dude wherever he goes
state HoldingItem extends Idle
{
	simulated function BeginState()
	{
	}
	// LockToPawn
	// Misnamed function, all this really does is turn off karma physics and make it so that the dude
	// isn't blocked by the item we're carrying.
	function LockToPawn(Actor Other)
	{
		//Other.KAddImpulse(Other.Velocity, Other.Location);
	    if ( ClassIsChildOf(Other.Class,class'P2Projectile') || ClassIsChildOf(Other.Class,class'FPSPawn') || ClassIsChildOf(Other.Class,class'Pickup') ){}
	    // Some things such as Projectiles and Pawns shouldn't have their
        // physics changd
        else // if what you have is neither of them
        Other.SetPhysics(PHYS_None); // turn off physics
		//Other.KDisableKarma();
		if (ClassIsChildOf(Other.Class,class'KActor'))
			OldbPawn = KActor(Other).bPawnMovesMe;
		if (ClassIsChildOf(Other.Class,class'KActorExplodable'))
			KActorExplodable(Other).bReadyForImpact=true;
		Other.bBlockPlayers=false; // turn off player collision.
		// Leaves other collisions on, so we can be annoying and screw with people if we want
	}

	// UpdateItem
	// this function moves the object in front of the dude
	// Also rotates the object relative to the dude's view rotation
	simulated function UpdateItem(Actor Other)
	{
		local vector HitNormal, StartTrace, EndTrace, X,Y,Z;
		local rotator foo;

		foo = Pawn(Owner).Controller.GetViewRotation();
		Other.SetRotation(foo); // set object's rotation relative to the dude's view
        GetAxes(foo, X, Y, Z);
		// crazy vector math
		// basically says "hold this item out in front of the dude"
		// if we look up or down the item will move with the view
		StartTrace = Owner.Location + (HoldDist*X) + (HoldDist*Z/3);
		Other.SetLocation(StartTrace);
		if ( FPSPawn(Other) != None )
		{
		    FPSPawn(Other).Velocity = (Vect(0,0,0));
		    // This is just here to stabalize the pawns, sort of cancels out
		    // the effects of gravity
            if ( FPSPawn(Other).Health == 0 )
                DropOurItem();
                // If they're dead, drop'em. We do this because the last time
                // I messed around with ragdolls, there's a chance you can walk
                // and then suddenly gib.
        }
        //if ( Pickup(Other) != None )
            //Pickup(Other).Vel
	}
	simulated event Tick(float Deltatime)
	{
		UpdateItem(OurHeldItem);
	}

// Beginning of state
Begin:
	LockToPawn(OurHeldItem); // Get our object ready for carrying
	if (OurHeldItem == None) // If our object goes away for some reason, go back to normal idling
		GotoState('Idle');
	//UpdateItem(OurHeldItem); // Position our object
}

state ChargingThrow extends HoldingItem
{
	ignores Fire, AltFire, ServerFire, ServerAltFire, TraceFire, TraceAltFire;

    simulated function RenderOverlays(Canvas Canvas)
	{
		local float ScreenX, ScreenY, Width, Height, Border, Perc;

		ScreenX = Canvas.SizeX/2;
		ScreenY = Canvas.SizeY*4/5;
		Width = Canvas.SizeX/4;
		Height = Canvas.SizeY/20;
		Border = 2;
		Perc = (Level.TimeSeconds-ChargeStart)/MAX_CHARGE_TIME;
		DrawPercBar(Canvas, ScreenX, ScreenY, Width, Height, Border, ProgressBarColor, Perc);
		Super.RenderOverlays(Canvas);
	}

	function LockToPawn(Actor Other);
	simulated event BeginState()
	{
		ChargeStart = Level.TimeSeconds;
	}
	simulated function FinishShot()
	{
		if (NotDedOnServer())
		{
			ChargeTime = Level.TimeSeconds - ChargeStart;
			TossOurItem(ChargeTime);
		}
		GotoState('Idle');
	}
	simulated event Tick(float DeltaTime)
	{
		UpdateItem(OurHeldItem);
		if (NotDedOnServer() && !Instigator.PressingAltFire() || Level.TimeSeconds-ChargeStart >= MAX_CHARGE_TIME)
		{
		    if ( Instigator.PressingFire() && FPSPawn(OurHeldItem) != None && Level.TimeSeconds-ChargeStart >= 1.9 )
		    // When we're fully charged, and if you're pressing or holding the
		    // fire button, then we're gonna gib them if what we're holding a
		    // pawn.
		    {
		        if ( P2Pawn(OurHeldItem) != None )
		        {
		        // If it's a person.
		            P2Pawn(OurHeldItem).TakeDamage( 1000, Instigator, P2Pawn(OurHeldItem).Location, (Vect(0,0,0)), Class'BaseFX.KickingDamage' ) ;
		            // Kill the pawn so it'll drop it's items then...
		            P2Pawn(OurHeldItem).ChunkUp(0);
		            // We finish, by gibbing
                    PawnHitMarkerMade.static.NotifyControllersStatic( Level, PawnHitMarkerMade, FPSPawn(Instigator), P2Pawn(OurHeldItem), PawnHitMarkerMade.default.CollisionRadius, P2Pawn(OurHeldItem).Location );
		            // Then we cause panic when people see someone just blow up.
                }
                if ( AnimalPawn(OurHeldItem) != None )
                // If it's an animal.
                    if ( ElephantPawn(OurHeldItem) != None )
                    // We can't gib elephants, so just throw'em.
                        FinishShot();
                    else
                        AnimalPawn(OurHeldItem).ChunkUp(0);
                        // Otherwise, we gib'em
            }
            else
            {
			    FinishShot();
			    // Otherwise, throw it.
		    }
        }
	}
}

// DownWeapon
// Drop anything we're carrying before we switch to some other weapon, usually a firearm to handle attackers
state DownWeapon
{
	simulated function BeginState()
	{
		DropOurItem();
		Super.Beginstate();
	}
}

// Active
// tell the player we're working
state Active
{
	function BeginState()
	{
		Super.BeginState();
		//P2Player(Instigator.Controller).ClientMessage("Karma Gun selected");
	}
}

defaultproperties
{
     LaughSound=Sound'DudeDialog.dude_hehhehheh'
     FlipoffSound=Sound'DudeDialog.dude_fuckyou'
     HoldDist=200.000000
     ThrowMomentum=100000.000000
     PThrowMomentum=3000.000000
     KThrowMomentum=250000.000000
     ErrorSound=Sound'MiscSounds.Bleeps.bleep1'
     bShowMainHints=True
     HudHint3="Press Fire to drop the object, or"
     HudHint4="hold Alt-Fire to charge a throw. "
     ProgressBarColor=(R=255,A=192)
     bUsesAltFire=True
     bArrestableWeapon=True
     ShakeOffsetTime=0.000000
     HudHint1="Aim at a karma object and press"
     HudHint2="Fire to pick it up.            "
     DropWeaponHint1="They've seen your weapon!"
     DropWeaponHint2="Press ; to drop it.      "
     bBumpStartsFight=False
     FirstPersonMeshSuffix="Nothing"
     WeaponSpeedLoad=1.000000
     WeaponSpeedReload=1.500000
     WeaponSpeedHolster=1.000000
     WeaponSpeedShoot1=1.000000
     WeaponSpeedShoot2=1.000000
     AltFireSound=Sound'AW7Sounds.KarmaGun.object_throw'
     AmmoName=Class'KarmaGun.KarmaAmmoInv'
     PickupClass=Class'KarmaGun.KarmaGunPickup'
     bCanThrow=False
     AutoSwitchPriority=0
     ShakeRotMag=(X=0.000000,Y=0.000000,Z=0.000000)
     ShakeRotRate=(X=0.000000,Y=0.000000,Z=0.000000)
     ShakeRotTime=0.000000
     ShakeOffsetMag=(X=0.000000,Y=0.000000,Z=0.000000)
     ShakeOffsetRate=(X=0.000000,Y=0.000000,Z=0.000000)
     aimerror=0.000000
     TraceDist=1000.000000
     FireSound=Sound'AW7Sounds.KarmaGun.catch'
     SelectSound=None
     GroupOffset=231
     BobDamping=0.975000
     AttachmentClass=None
     ItemName="Karma gun"
     Mesh=SkeletalMesh'MP_Weapons.MP_LS_Nothing'
     Skins(0)=Texture'MP_FPArms.LS_arms.LS_hands_dude'
}
